package com.ruoyi.llm.service;

import com.ruoyi.llm.domain.CmcTopic;

import java.util.List;

/**
 * cmc聊天主题Service接口
 * 
 * @author cmc
 * @date 2025-04-08
 */
public interface ICmcTopicService 
{
    /**
     * 查询cmc聊天主题
     * 
     * @param topicId cmc聊天主题主键
     * @return cmc聊天主题
     */
    public CmcTopic selectCmcTopicByTopicId(String topicId);

    /**
     * 查询cmc聊天主题列表
     * 
     * @param cmcTopic cmc聊天主题
     * @return cmc聊天主题集合
     */
    public List<CmcTopic> selectCmcTopicList(CmcTopic cmcTopic);

    /**
     * 新增cmc聊天主题
     * 
     * @param cmcTopic cmc聊天主题
     * @return 结果
     */
    public int insertCmcTopic(CmcTopic cmcTopic);

    /**
     * 修改cmc聊天主题
     * 
     * @param cmcTopic cmc聊天主题
     * @return 结果
     */
    public int updateCmcTopic(CmcTopic cmcTopic);

    /**
     * 批量删除cmc聊天主题
     * 
     * @param topicIds 需要删除的cmc聊天主题主键集合
     * @return 结果
     */
    public int deleteCmcTopicByTopicIds(String[] topicIds);

    /**
     * 删除cmc聊天主题信息
     * 
     * @param topicId cmc聊天主题主键
     * @return 结果
     */
    public int deleteCmcTopicByTopicId(String topicId);
}
